@@ -1,5 +1,5 @@
 from .azureblobmapping import AzureBlobMapping
 
 __all__ = [
-    'AzureBlobMapping',
+    "AzureBlobMapping",
 ]
